module.exports = defineTest({
	description: 'does not fail for double declarations with initializers from other modules'
});
